@@ -35,11 +35,21 @@ main (int argc, char **argv)
         GtkWidget     *window;
         GError        *error;
 
+#ifdef ENABLE_NLS
+        bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+# ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+# endif
+        textdomain (GETTEXT_PACKAGE);
+#endif
+
         error = NULL;
 
         gtk_init_with_args (&argc, &argv, NULL, NULL, NULL, &error);
 
         window = gs_theme_window_new ();
+        g_signal_connect (G_OBJECT (window), "delete-event",
+                          G_CALLBACK (gtk_main_quit), NULL);
 
         g_set_prgname ("popsquares");
 
